﻿using System;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.WebEdition;

public partial class _Default : System.Web.UI.Page, ICallbackEventHandler
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
            Map1.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
            Map1.MapUnit = GeographyUnit.DecimalDegree;

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(MapPath("~/app_data/states.shp"));
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 243, 239, 228), GeoColor.FromArgb(255, 218, 193, 163), 1);
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            InMemoryFeatureLayer highlightLayer = new InMemoryFeatureLayer();
            highlightLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100, 60, 180, 60), GeoColor.GeographicColors.DeepOcean);
            highlightLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.Country1("CNTRY_NAME");
            highlightLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            highlightLayer.DrawingMarginPercentage = 50;

            Map1.StaticOverlay.Layers.Add("WorldLayer", worldLayer);
            Map1.DynamicOverlay.Layers.Add("HighlightLayer", highlightLayer);

            Map1.OnClientClick = "raiseHightlightOverlay";
        }
    }

    #region ICallbackEventHandler Members

    public string GetCallbackResult()
    {
        return String.Empty;
    }

    public void RaiseCallbackEvent(string eventArgument)
    {
        string[] args = eventArgument.Split(',');
        double longitude = Double.Parse(args[0]);
        double latitude = Double.Parse(args[1]);
        PointShape clickPoint = new PointShape(longitude, latitude);

        ShapeFileFeatureLayer worldLayer = (ShapeFileFeatureLayer)Map1.StaticOverlay.Layers["WorldLayer"];
        InMemoryFeatureLayer highlightLayer = (InMemoryFeatureLayer)Map1.DynamicOverlay.Layers["HighlightLayer"];

        highlightLayer.InternalFeatures.Clear();
        worldLayer.Open();
        Collection<Feature> features = worldLayer.QueryTools.GetFeaturesContaining(clickPoint, new string[] { });
        worldLayer.Close();

        if (features.Count > 0)
        {
            highlightLayer.InternalFeatures.Add(features[0].Id, features[0]);
        }

        Map1.DynamicOverlay.Redraw();
    }

    #endregion
}


